@@ -26,7 +26,7 @@
  * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
  */
 
-/* $Header: gen.c,v 1.2 94/01/04 14:33:12 vern Exp $ */
+/* $Header: /home/daffy/u0/vern/flex/flex-2.4.7/RCS/gen.c,v 1.3 94/08/03 11:37:45 vern Exp $ */
 
 #include "flexdef.h"
 
@@ -1055,7 +1055,8 @@ void make_tables()
 		indent_puts(
 		"YY_FATAL_ERROR( \"token too large, exceeds YYLMAX\" ); \\" );
 		indent_down();
-		indent_puts( "yy_flex_strcpy( yytext, yytext_ptr ); \\" );
+		indent_puts(
+		"yy_flex_strncpy( yytext, yytext_ptr, yyleng + 1 ); \\" );
 		}
 
 	set_indent( 0 );
@@ -1394,7 +1395,7 @@ void make_tables()
 	/* Generate code for handling NUL's, if needed. */
 
 	/* First, deal with backing up and setting up yy_cp if the scanner
-	 * finds that it should JAM on the NUL>
+	 * finds that it should JAM on the NUL.
 	 */
 	skelout();
 	set_indent( 7 );
@@ -1413,6 +1414,13 @@ void make_tables()
 			indent_puts(
 				"yy_current_state = yy_last_accepting_state;" );
 			}
+
+		else
+			/* Still need to initialize yy_cp, though
+			 * yy_current_state was set up by
+			 * yy_get_previous_state().
+			 */
+			indent_puts( "yy_cp = yy_c_buf_p;" );
 		}
 
 
